# Electronics Production

#### group assignment:

- characterize the design rules for your in-house PCB production process

## Workflow to produce electronic circuits

### Cheatsheet

**Context**: You already have the design of the board you'd like to use, and you are happy with it (no design changes
required).

This assumes that the designs have been customized for the machine that you will be using: e.g. Since the machine will
use a 1/64th inch milling bit, the traces will need to be at least 1/64th inch separated from each other, etc..

If this is not the case, you might have to customize your board design. Check out our documentation from **Week 06
Electronics Design**.

#### Creating the milling programs

1. Load the design into [mods](http://modsproject.org/) and load the custom program for the Roland SRM-20 that you can
   find in the Barcelona Lab.
    1. You can
       find [the customized programs for milling and cutting](https://fabacademy.org/2022/labs/barcelona/students/eduard-almasque/assignments/04-electronics-production/week04-creating-basic-boards/#automating-these-almost-perfect-programs)
       in Edu's documentation
2. You will use the milling program to mill the traces, and the cutting program to cut out the outline of your board.
    1. Load the custom program into mods by:
        1. Right-clicking on an empty space, and choosing "Programs > Open program from file"
        2. Load the milling program you downloaded
        3. This program has been customized for the Barcelona Lab machines, so you don't have to customize any other
           settings.
        4. If you cannot use this custom program, you will have to customize the settings manually.
           See [custom settings section](#manually-configuring-settings) for a detailed breakdown.
    2. Load the traces file that has the design of your board (PNG or SVG)
    3. Click "Calculate" and the \*.RML file will be downloaded
        1. You will use this file to mill your traces when you are on the Roland machine
    4. Repeat the process with the cutting programme, and the outline file
        1. This will give you the RML file to do the outline.

### Launching the milling programs

3. Book time in the Roland SRM-20 machine.
    1. lol. no one ever does it!
4. Go to the computer lab, and launch the _V-Panel for SRM-20_ app. This application is used to send milling jobs to the
   Roland SRM-20 machine.
5. Get a new blank board.
    1. Stick it to the bed with double-sided tape.
    2. Make sure you cover the entire surface to avoid it moving out of place.
6. Load the 1/64th inch. milling bit (for tracing) into the machine
    1. Remember to hold it in place with your finger while you tighten it, to make sure it doesn't fall off and break
       while you are tightening it.
7. Configure the 0,0 for X and Y axis
    1. Close the safety cover
    2. Use the VPanel app to move the milling bit to the starting coordinates for X and Y only.
    3. Click on the "X/Y" button under the "Set origin point" in order to configure those to 0,0
8. Configure the 0 for the Z axis
    1. ⚠️This is the dangerous (expensive) step, if you do it wrong/carelessly
    2. You need to move the milling bit close to the board, without it touching.
    3. You will need to carefully unscrew the bit and lower it gently by hand until it rests on top of the board.
    4. Once it is resting on top of the board, tighten it again, while still holding it in place to avoid it going
       up/down.
    5. Click on the "Z" button under the "Set origin point"
9. Validate your settings (Optional)
    1. You can lift the spindle up a few mm
    2. Turn on the spindle. Wait until it reaches 10k rpm.
    3. Lower it very slowly until it reaches Z = 0 and see if it's touching the board and milling a tiny dot into it.
    4. If it's not milling properly, you Z is set too high, and you should readjust.
10. You have successfully calibrated your equipment. 👯‍♂️👯‍♀️🎉
11. You are not ready to load the RML file into the application.
    1. Click the "Cut" button.
    2. Delete any pending tasks that might be on the list.
    3. Click on "Add" to load your file
    4. ⚠ Mill the job!
        1. Click on Output to launch the milling job
12. Other tips:
    1. You can always pause the job to check out what it looks like, and resume later.
    2. You can cancel the job to fully stop the operation. This will not let you resume and you will have to restart the
       job from the beginning.

### Launching the cutting programs

Repeat the steps above, but load the 1/32 inch. into the spindle instead of the 1/64 inch one ⚠️IMPORTANT: You will need
to recalibrate the Z axis only!

### Manually Configuring Settings

#### Milling settings

1. Make sure that your file has a **DPI of 1000**
2. Under _PCB Defaults_ module;
    1. Set offset number to **4**
    2. Set speed to **3mm/s**
    3. ![](week04-our-first-board/set-pcb-defaults.jpg)
3. Under _Roland SRM-20 Absolute Coordinate_ module:
    1. Set speed to 3mm/s
    2. Origin to **0,0,0**
    3. Jog height to **10mm**
    4. Set Z coordinate for home to **20mm**
    5. ![](week04-our-first-board/roland-coordinate-settings.jpg)
4. Under the _mill-raster 2D_ module:
    1. Check if the offset number is **4**
    2. Check that direction is set to **Climb**
    3. ![](week04-our-first-board/read-png.jpg)
5. Connect a line between the _Absolute Coordinates_ module (the _output_ node) to the "Save File" module.
6. Click on _Calculate_ and the RML will automatically be downloaded by your browser

#### Cutting settings

Cutting the outline uses the same settings except for these small tweaks

2. Under _PCB Defaults_ module;
    1. Set offset number to **1**
    2. Set speed to **1.5mm/s**
3. Under _Mill Raster 2D_ module:
    1. Set Max depth: set 1.75mm

![](week04-our-first-board/mill-raster.jpg)

## Our lab equipment

### Roland SRM-20

Our barcelona lab has a couple Roland SRM-20 milling machines.

![](week04-our-first-board/srm20_png.png)

### Testing our machine tolerances

![](week04-our-first-board/linetest.png)

During week 3, we had to test and find out what are the tolerances for our equipment, so we could make important design
decisions when milling and designing new boards.

![](week04-our-first-board/milling-tolerances.jpg)

To find out, we printed out a test board and this is the result.

#### Conclusions:

**Physical Constraints**: When cutting from the outside, anything under 0.007mm will be scraped off and will not have any copper material left.

**Mods Logic**: When cutting from the inside, anything under 0.014mm will not be cut, as the milling bit is too wide, and Mods will not
allow it to get milled.

### Documented by:

- [Dhanu](https://fabacademy.org/2022/labs/barcelona/students/dhanushree-prakash/)
- [Adai](https://fabacademy.org/2022/labs/barcelona/students/adai-surinac/)
- [Edu](https://fabacademy.org/2022/labs/barcelona/students/eduard-almasque/)